@@ -1,5 +1,5 @@
 package Bot::Cobalt::Plugin::Seen;
-$Bot::Cobalt::Plugin::Seen::VERSION = '0.017008';
+$Bot::Cobalt::Plugin::Seen::VERSION = '0.018001';
 use 5.10.1;
 
 use Bot::Cobalt;
@@ -312,7 +312,7 @@ sub Bot_public_cmd_seen {
   my $meta = $ref->{Meta} // {};
 
   my $ts_delta = time - $last_ts ;
-  my $ts_str   = secs_to_str($ts_delta);
+  my $ts_str   = secs_to_str_y($ts_delta);
 
   my $resp;
   ACTION: {
