@@ -1,5 +1,5 @@
 package Bot::Cobalt::Utils;
-$Bot::Cobalt::Utils::VERSION = '0.017008';
+$Bot::Cobalt::Utils::VERSION = '0.018001';
 use strictures 2;
 use Carp;
 use Scalar::Util 'reftype';
@@ -10,6 +10,7 @@ use parent 'Exporter::Tiny';
 
 our @EXPORT_OK = qw/
   secs_to_str
+  secs_to_str_y
   secs_to_timestr
   timestr_to_secs
 
@@ -22,8 +23,6 @@ our @EXPORT_OK = qw/
   glob_to_re
   glob_to_re_str
   rplprintf
-
-  %COLORS
 /;
 
 our %EXPORT_TAGS = (
@@ -235,7 +234,7 @@ sub color ($;$) {
     unless $selected;
 
   return $selected . $str . $COLORS{NORMAL} if $str;
-  return $selected || $COLORS{NORMAL};
+  $selected || $COLORS{NORMAL};
 }
 
 
@@ -288,13 +287,12 @@ sub _time_breakdown ($) {
   my $hours  = int $sec / 3600;  $sec   %= 3600;
   my $mins   = int $sec / 60;    $sec   %= 60;
 
-  return($days, $hours, $mins, $sec)
+  ($days, $hours, $mins, $sec)
 }
 
 sub secs_to_timestr ($) {
   my ($diff) = @_;
   return unless defined $diff;
-
   my ($days, $hours, $mins, $sec) = _time_breakdown($diff);
 
   my $str;
@@ -310,12 +308,21 @@ sub secs_to_str ($) {
   ## turn seconds into a string like '0 days, 00:00:00'
   my ($diff) = @_;
   return unless defined $diff;
-
   my ($days, $hours, $mins, $sec) = _time_breakdown($diff);
+  sprintf "%d days, %2.2d:%2.2d:%2.2d", $days, $hours, $mins, $sec
+}
 
-  return sprintf("%d days, %2.2d:%2.2d:%2.2d",
-    $days, $hours, $mins, $sec
-  );
+sub secs_to_str_y {
+  my ($diff) = @_;
+  return unless defined $diff;
+  my ($days, $hrs, $mins, $sec) = _time_breakdown($diff);
+  my $yrs = int $days / 365;   $days %= 365;
+  my $plural = $yrs > 1 ? 'years' : 'year';
+  $yrs ?
+    sprintf "%d $plural, %d days, %2.2d:%2.2d:%2.2d",
+      $yrs, $days, $hrs, $mins, $sec
+    : sprintf "%d days, %2.2d:%2.2d:%2.2d",
+        $days, $hrs, $mins, $sec
 }
 
 
@@ -427,7 +434,15 @@ Useful for uptime reporting, for example:
   my $delta = time() - $your_start_TS;
   my $uptime_str = secs_to_str $delta;
 
+Returns time formatted as: C<< <D> days, <H>:<M>:<S> >>
 
+=head3 secs_to_str_y
+
+Like L</secs_to_str>, but includes year calculation and returns time formatted
+as: C<< <Y> years, <D> days, <H>:<M>:<S> >> B<if> there are more than 365
+days; otherwise the same format as L</secs_to_str> is returned.
+
+(Added in C<v0.18.1>)
 
 =head2 String Formatting
 
@@ -457,9 +472,11 @@ string, terminated by NORMAL:
 
   my $formatted = color('red', "red text") . "normal text";
 
-The hash B<%COLORS> is exported as part of I<:ALL>. Its keys are the 
-same as the formatting/color names listed above. You should really use 
-C<color()> instead.
+If you need to retrieve (or alter via C<local>, for example) the actual
+control characters themselves, they are accessible via the C<<
+%Bot::Cobalt::Utils::COLORS >> hash:
+
+  my $red = $Bot::Cobalt::Utils::COLORS{RED}
 
 =head3 glob_to_re_str
 
